---
title: Datasets
---

The Dataset classes define the data model behind Open Targets Gentropy. Every class inherits from the `Dataset` class and contains a dataframe with a predefined schema that can be found in the respective classes.

::: gentropy.dataset.dataset.Dataset
